package com.chelvc.cloud.vehicle.api.service;

import java.util.List;

import com.chelvc.cloud.vehicle.api.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.api.dto.MerchantDetailDTO;
import com.chelvc.cloud.vehicle.api.param.MerchantQueryParam;
import com.chelvc.cloud.vehicle.api.param.NearbyQueryParam;
import com.chelvc.cloud.vehicle.api.param.PointQueryParam;

/**
 * 商家业务接口
 *
 * @author Woody
 * @date 2023/5/4
 */
public interface MerchantService {
    /**
     * 获取推荐商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listRecommendMerchants(PointQueryParam param, int size);

    /**
     * 获取附近商家
     *
     * @param param 查询参数
     * @param size  商家数量
     * @return 商家信息列表
     */
    List<MerchantDTO> listNearbyMerchants(NearbyQueryParam param, int size);

    /**
     * 查询商家
     *
     * @param param 查询参数
     * @return 商家信息列表
     */
    List<MerchantDTO> listSimpleMerchants(MerchantQueryParam param);

    /**
     * 获取商家详情
     *
     * @param id 商家ID
     * @return 商家详情
     */
    MerchantDetailDTO getMerchantDetail(Long id);
}
