package com.chelvc.cloud.vehicle.server.copier;

import com.chelvc.cloud.vehicle.api.constant.FavoriteType;
import com.chelvc.cloud.vehicle.api.dto.CategoryDTO;
import com.chelvc.cloud.vehicle.api.dto.FavoriteDTO;
import com.chelvc.cloud.vehicle.api.param.CategoryModifyParam;
import com.chelvc.cloud.vehicle.api.param.FavoriteModifyParam;
import com.chelvc.cloud.vehicle.server.entity.Category;
import com.chelvc.cloud.vehicle.server.entity.Favorite;
import org.mapstruct.*;
import org.mapstruct.factory.Mappers;

import java.util.Collection;
import java.util.List;

/**
 * 收藏信息拷贝接口
 *
 * @author Woody
 * @date 2023/5/2
 */
@Mapper(builder = @Builder(disableBuilder = true))
public interface FavoriteCopier {
    /**
     * 对象拷贝接口实例
     */
    FavoriteCopier INSTANCE = Mappers.getMapper(FavoriteCopier.class);

    /**
     * 收藏信息拷贝
     *
     * @param favorite 收藏信息
     * @return 收藏信息
     */
    @Named("entity2dto")
    FavoriteDTO copying(Favorite favorite);

    /**
     * 收藏信息拷贝
     *
     * @param favorites 收藏信息集合
     * @return 收藏信息列表
     */
    @IterableMapping(qualifiedByName = "entity2dto")
    List<FavoriteDTO> copying(Collection<Favorite> favorites);

    /**
     * 收藏信息拷贝
     *
     * @param param 收藏更新参数
     * @return 收藏信息
     */
    Favorite copying(FavoriteModifyParam param);

    /**
     * 收藏信息拷贝
     *
     * @param param    收藏更新参数
     * @param favorite 收藏信息
     */
    void copying(FavoriteModifyParam param, @MappingTarget Favorite favorite);
}
